@@ -26,8 +26,9 @@ from ironic_inspector import utils
 CONF = cfg.CONF
 LOG = utils.getProcessingLogger(__name__)
 
-# See http://specs.openstack.org/openstack/ironic-specs/specs/kilo/new-ironic-state-machine.html  # noqa
-VALID_STATES = {'enroll', 'manageable', 'inspecting', 'inspect failed'}
+# See https://docs.openstack.org/ironic/latest/contributor/states.html  # noqa
+VALID_STATES = {'enroll', 'manageable', 'inspecting', 'inspect wait',
+                'inspect failed'}
 
 # 1.19 is API version, which supports port.pxe_enabled
 DEFAULT_IRONIC_API_VERSION = '1.19'
@@ -53,43 +54,18 @@ def reset_ironic_session():
 
 
 def get_ipmi_address(node):
-    """Get the BMC address defined in node.driver_info dictionary
-
-    Possible names of BMC address value examined in order of list
-    ['ipmi_address'] + CONF.ipmi_address_fields. The value could
-    be an IP address or a hostname. DNS lookup performed for the
-    first non empty value.
-
-    The first valid BMC address value returned along with
-    it's v4 and v6 IP addresses.
-
-    :param node: Node object with defined driver_info dictionary
-    :return: tuple (ipmi_address, ipv4_address, ipv6_address)
-    """
-    none_address = None, None, None
     ipmi_fields = ['ipmi_address'] + CONF.ipmi_address_fields
     # NOTE(sambetts): IPMI Address is useless to us if bridging is enabled so
     # just ignore it and return None
     if node.driver_info.get("ipmi_bridging", "no") != "no":
-        return none_address
+        return
     for name in ipmi_fields:
         value = node.driver_info.get(name)
         if not value:
             continue
 
-        ipv4 = None
-        ipv6 = None
         try:
-            addrinfo = socket.getaddrinfo(value, None, 0, 0, socket.SOL_TCP)
-            for family, socket_type, proto, canon_name, sockaddr in addrinfo:
-                ip = sockaddr[0]
-                if netaddr.IPAddress(ip).is_loopback():
-                    LOG.warning('Ignoring loopback BMC address %s', ip,
-                                node_info=node)
-                elif family == socket.AF_INET:
-                    ipv4 = ip
-                elif family == socket.AF_INET6:
-                    ipv6 = ip
+            ip = socket.gethostbyname(value)
         except socket.gaierror:
             msg = _('Failed to resolve the hostname (%(value)s)'
                     ' for node %(uuid)s')
@@ -97,8 +73,12 @@ def get_ipmi_address(node):
                                      'uuid': node.uuid},
                               node_info=node)
 
-        return (value, ipv4, ipv6) if ipv4 or ipv6 else none_address
-    return none_address
+        if netaddr.IPAddress(ip).is_loopback():
+            LOG.warning('Ignoring loopback BMC address %s', ip,
+                        node_info=node)
+            ip = None
+
+        return ip
 
 
 def get_client(token=None,
