@@ -197,12 +197,6 @@ class TestExclusiveWriteOrPass(test_base.BaseTest):
 class TestMACHandlers(test_base.BaseTest):
     def setUp(self):
         super(TestMACHandlers, self).setUp()
-        self.mock_listdir = self.useFixture(
-            fixtures.MockPatchObject(os, 'listdir')).mock
-        self.mock_stat = self.useFixture(
-            fixtures.MockPatchObject(os, 'stat')).mock
-        self.mock_remove = self.useFixture(
-            fixtures.MockPatchObject(os, 'remove')).mock
         self.mac = 'ff:ff:ff:ff:ff:ff'
         self.dhcp_hostsdir = '/far'
         CONF.set_override('dhcp_hostsdir', self.dhcp_hostsdir,
@@ -253,26 +247,6 @@ class TestMACHandlers(test_base.BaseTest):
             'A %s record for all unknown hosts using wildcard mac '
             'created', 'blacklist')
 
-    def test__configure_removedlist_whitelist(self):
-        self.mock_introspection_active.return_value = True
-        self.mock_stat.return_value.st_size = dnsmasq._MACBL_LEN
-
-        dnsmasq._configure_removedlist({self.mac})
-
-        self.mock_join.assert_called_with(self.dhcp_hostsdir, self.mac)
-        self.mock__exclusive_write_or_pass.assert_called_once_with(
-            self.mock_join.return_value, '%s\n' % self.mac)
-
-    def test__configure_removedlist_blacklist(self):
-        self.mock_introspection_active.return_value = False
-        self.mock_stat.return_value.st_size = dnsmasq._MACWL_LEN
-
-        dnsmasq._configure_removedlist({self.mac})
-
-        self.mock_join.assert_called_with(self.dhcp_hostsdir, self.mac)
-        self.mock__exclusive_write_or_pass.assert_called_once_with(
-            self.mock_join.return_value, '%s,ignore\n' % self.mac)
-
     def test__whitelist_mac(self):
         dnsmasq._whitelist_mac(self.mac)
 
@@ -290,42 +264,22 @@ class TestMACHandlers(test_base.BaseTest):
     def test__get_blacklist(self):
         self.mock_listdir.return_value = [self.mac]
         self.mock_stat.return_value.st_size = len('%s,ignore\n' % self.mac)
-        blacklist, whitelist = dnsmasq._get_black_white_lists()
+        ret = dnsmasq._get_blacklist()
 
-        self.assertEqual({self.mac}, blacklist)
+        self.assertEqual({self.mac}, ret)
         self.mock_listdir.assert_called_once_with(self.dhcp_hostsdir)
-        self.mock_join.assert_called_with(self.dhcp_hostsdir, self.mac)
-        self.mock_stat.assert_called_with(self.mock_join.return_value)
-
-    def test__get_whitelist(self):
-        self.mock_listdir.return_value = [self.mac]
-        self.mock_stat.return_value.st_size = len('%s\n' % self.mac)
-        blacklist, whitelist = dnsmasq._get_black_white_lists()
-
-        self.assertEqual({self.mac}, whitelist)
-        self.mock_listdir.assert_called_once_with(self.dhcp_hostsdir)
-        self.mock_join.assert_called_with(self.dhcp_hostsdir, self.mac)
-        self.mock_stat.assert_called_with(self.mock_join.return_value)
+        self.mock_join.assert_called_once_with(self.dhcp_hostsdir, self.mac)
+        self.mock_stat.assert_called_once_with(self.mock_join.return_value)
 
     def test__get_no_blacklist(self):
         self.mock_listdir.return_value = [self.mac]
         self.mock_stat.return_value.st_size = len('%s\n' % self.mac)
-        blacklist, whitelist = dnsmasq._get_black_white_lists()
+        ret = dnsmasq._get_blacklist()
 
-        self.assertEqual(set(), blacklist)
+        self.assertEqual(set(), ret)
         self.mock_listdir.assert_called_once_with(self.dhcp_hostsdir)
-        self.mock_join.assert_called_with(self.dhcp_hostsdir, self.mac)
-        self.mock_stat.assert_called_with(self.mock_join.return_value)
-
-    def test__get_no_whitelist(self):
-        self.mock_listdir.return_value = [self.mac]
-        self.mock_stat.return_value.st_size = len('%s,ignore\n' % self.mac)
-        blacklist, whitelist = dnsmasq._get_black_white_lists()
-
-        self.assertEqual(set(), whitelist)
-        self.mock_listdir.assert_called_once_with(self.dhcp_hostsdir)
-        self.mock_join.assert_called_with(self.dhcp_hostsdir, self.mac)
-        self.mock_stat.assert_called_with(self.mock_join.return_value)
+        self.mock_join.assert_called_once_with(self.dhcp_hostsdir, self.mac)
+        self.mock_stat.assert_called_once_with(self.mock_join.return_value)
 
     def test__purge_dhcp_hostsdir(self):
         self.mock_listdir.return_value = [self.mac]
@@ -338,6 +292,8 @@ class TestMACHandlers(test_base.BaseTest):
 
     def test_disabled__purge_dhcp_hostsdir(self):
         CONF.set_override('purge_dhcp_hostsdir', False, 'dnsmasq_pxe_filter')
+        # NOTE(dtantsur): set_override uses os.path internally
+        self.mock_join.reset_mock()
 
         dnsmasq._purge_dhcp_hostsdir()
         self.mock_listdir.assert_not_called()
@@ -348,16 +304,14 @@ class TestMACHandlers(test_base.BaseTest):
 class TestSync(DnsmasqTestBase):
     def setUp(self):
         super(TestSync, self).setUp()
-        self.mock__get_black_white_lists = self.useFixture(
-            fixtures.MockPatchObject(dnsmasq, '_get_black_white_lists')).mock
+        self.mock__get_blacklist = self.useFixture(
+            fixtures.MockPatchObject(dnsmasq, '_get_blacklist')).mock
         self.mock__whitelist_mac = self.useFixture(
             fixtures.MockPatchObject(dnsmasq, '_whitelist_mac')).mock
         self.mock__blacklist_mac = self.useFixture(
             fixtures.MockPatchObject(dnsmasq, '_blacklist_mac')).mock
         self.mock__configure_unknown_hosts = self.useFixture(
             fixtures.MockPatchObject(dnsmasq, '_configure_unknown_hosts')).mock
-        self.mock__configure_removedlist = self.useFixture(
-            fixtures.MockPatchObject(dnsmasq, '_configure_removedlist')).mock
 
         self.mock_ironic = mock.Mock()
         self.mock_utcnow = self.useFixture(
@@ -376,10 +330,8 @@ class TestSync(DnsmasqTestBase):
             fixtures.MockPatchObject(node_cache, 'active_macs')).mock
         self.ironic_macs = {'new_mac', 'active_mac'}
         self.active_macs = {'active_mac'}
-        self.blacklist = {'gone_mac', 'active_mac'}
-        self.whitelist = {}
-        self.mock__get_black_white_lists.return_value = (self.blacklist,
-                                                         self.whitelist)
+        self.blacklist_macs = {'gone_mac', 'active_mac'}
+        self.mock__get_blacklist.return_value = self.blacklist_macs
         self.mock_ironic.port.list.return_value = [
             mock.Mock(address=address) for address in self.ironic_macs]
         self.mock_active_macs.return_value = self.active_macs
@@ -403,15 +355,16 @@ class TestSync(DnsmasqTestBase):
     def test__sync(self):
         self.driver._sync(self.mock_ironic)
 
-        self.mock__whitelist_mac.assert_called_once_with('active_mac')
-        self.mock__blacklist_mac.assert_called_once_with('new_mac')
-
+        self.mock__whitelist_mac.assert_has_calls([mock.call('active_mac'),
+                                                   mock.call('gone_mac')],
+                                                  any_order=True)
+        self.mock__blacklist_mac.assert_has_calls([mock.call('new_mac')],
+                                                  any_order=True)
         self.mock_ironic.port.list.assert_called_once_with(limit=0,
                                                            fields=['address'])
         self.mock_active_macs.assert_called_once_with()
-        self.mock__get_black_white_lists.assert_called_once_with()
+        self.mock__get_blacklist.assert_called_once_with()
         self.mock__configure_unknown_hosts.assert_called_once_with()
-        self.mock__configure_removedlist.assert_called_once_with({'gone_mac'})
         self.mock_log.debug.assert_has_calls([
             mock.call('Syncing the driver'),
             mock.call('The dnsmasq PXE filter was synchronized (took %s)',
@@ -426,14 +379,15 @@ class TestSync(DnsmasqTestBase):
         ]
         self.driver._sync(self.mock_ironic)
 
-        self.mock__whitelist_mac.assert_called_once_with('active_mac')
-        self.mock__blacklist_mac.assert_called_once_with('new_mac')
-
+        self.mock__whitelist_mac.assert_has_calls([mock.call('active_mac'),
+                                                   mock.call('gone_mac')],
+                                                  any_order=True)
+        self.mock__blacklist_mac.assert_has_calls([mock.call('new_mac')],
+                                                  any_order=True)
         self.mock_ironic.port.list.assert_called_with(limit=0,
                                                       fields=['address'])
         self.mock_active_macs.assert_called_once_with()
-        self.mock__get_black_white_lists.assert_called_once_with()
-        self.mock__configure_removedlist.assert_called_once_with({'gone_mac'})
+        self.mock__get_blacklist.assert_called_once_with()
         self.mock_log.debug.assert_has_calls([
             mock.call('Syncing the driver'),
             mock.call('The dnsmasq PXE filter was synchronized (took %s)',
